/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: mnstr-tab.h,v 1.5 2006/01/12 08:51:38 bowkenken Exp $
***************************************************************/

#ifndef	MNSTR_TAB_H
#define	MNSTR_TAB_H

#include	"party.h"
#include	"fight.h"
#include	"mnstr-act-prot.h"

/***************************************************************
* 󥹥Υǡơ֥
***************************************************************/

/* 㥤ƥåƥԡɤΤĹ */
#define	GIGANTIC_CENTIPEDE_LINK_N	8

/***************************************************************
* NPC Υꥹ
***************************************************************/

mnstr_kind_t	g_ls_npc_kind[] = {
	MNSTR_KIND_FIGHTER,
	MNSTR_KIND_MONK,
	MNSTR_KIND_HUNTER,
	MNSTR_KIND_THIEF,
	MNSTR_KIND_WIZARD,
	MNSTR_KIND_SUMMONER,
	MNSTR_KIND_PRIEST,
	MNSTR_KIND_SHAMAN,
	MNSTR_KIND_BARD,
	MNSTR_KIND_NINJA,
	MNSTR_KIND_BISHOP,

	MNSTR_KIND_FARMER,
	MNSTR_KIND_CRAFTSMAN,
	MNSTR_KIND_MERCHANT,

	MNSTR_KIND_NULL,
};

/***************************************************************
* 󥹥ǡ
***************************************************************/

mnstr_tab_t	mnstr_tab[] = {
#include	"mnstr-gen-tab.h"
};

/***************************************************************
* ܥΥꥹ
***************************************************************/

#if	0
typedef struct {
	/* 󥹥μ */
	mnstr_kind_t	kind;

	/* ȯ볬κǾκʬ */
	long	add_lev, range_lev;

	/* ȯ볬κǾ */
	/* ؿǼư׻ */
	long	min_lev, max_lev;
} mnstr_lev_tab_t;
#endif

mnstr_lev_tab_t	mnstr_boss_lev_tab[] = {
	{ MNSTR_KIND_HIGH_RE_HOO,	/*  */
		+0, +1, },
	{ MNSTR_KIND_GREAT_MINOTAUR,	/* Ⱦ */
		+0, +1, },
	{ MNSTR_KIND_BLACK_UNICORN,	/*  */
		+0, +1, },
	{ MNSTR_KIND_MEDUSA_ZOMBIE,	/* Ⱦ */
		+0, +1, },
	{ MNSTR_KIND_GIGANTIC_CENTIPEDE,	/* ʪ */
		+0, +1, },
	{ MNSTR_KIND_VAMPIRE_LORD,	/* ǥå */
		+0, +1, },
	{ MNSTR_KIND_NULL,
		+0, +0, },
};

/***************************************************************
* 󥹥νиꥹ
***************************************************************/

mnstr_lev_tab_t	mnstr_lev_tab[] = {
	{ MNSTR_KIND_FIGHTER,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_MONK,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_HUNTER,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_THIEF,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_WIZARD,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_SUMMONER,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_PRIEST,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_SHAMAN,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_BARD,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_NINJA,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_BISHOP,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_FARMER,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_CRAFTSMAN,	/* ʹ */
		+0, +1, },
	{ MNSTR_KIND_MERCHANT,	/* ʹ */
		+0, +1, },
	/**/

	{ MNSTR_KIND_GIANT_BAT,	/* ưʪ */
		+1, +1, },
	{ MNSTR_KIND_GIANT_SNAKE,	/* ưʪ */
		+0, +1, },
	{ MNSTR_KIND_GIANT_RAT,	/* ưʪ */
		+1, +1, },
	{ MNSTR_KIND_GIANT_CENTIPEDE,	/*  */
		+0, +1, },
	{ MNSTR_KIND_KOBOLD,	/*  */
		+1, +5, },
	{ MNSTR_KIND_VIPER_SNAKE,	/* ưʪ */
		+0, +1, },
	{ MNSTR_KIND_GOBLIN,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GIANT_BEE,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GREMLIN,	/*  */
		+1, +5, },
	{ MNSTR_KIND_HOBGOBLIN,	/*  */
		+1, +5, },
	{ MNSTR_KIND_CAT,	/* ưʪ */
		+0, +1, },
	{ MNSTR_KIND_DOG,	/* ưʪ */
		+0, +1, },
	{ MNSTR_KIND_WOLF,	/* ưʪ */
		+0, +1, },
	{ MNSTR_KIND_PYON_PYON,	/*  */
		+0, +1, },
	{ MNSTR_KIND_SKELETON,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_ORK,	/*  */
		+1, +5, },
	{ MNSTR_KIND_VENUS_FLY_TRAP,	/* ʪ */
		+1, +5, },
	{ MNSTR_KIND_GIANT_SCORPION,	/*  */
		+1, +5, },
	{ MNSTR_KIND_ZOMBIE,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_YETI,	/*  */
		+1, +5, },
	{ MNSTR_KIND_RUST_MONSTER,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GNOLL,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GIANT_ANT,	/*  */
		+1, +5, },
	{ MNSTR_KIND_OGRE,	/*  */
		+1, +5, },
	{ MNSTR_KIND_HARPY,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_LEPRECHAUN,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GHOUL,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_GIANT_SPIDER,	/*  */
		+1, +5, },
	{ MNSTR_KIND_SLIME,	/* ʪ */
		+1, +5, },
	{ MNSTR_KIND_IMP,	/*  */
		+1, +5, },
	{ MNSTR_KIND_TROLL,	/*  */
		+1, +5, },
	{ MNSTR_KIND_INVISIBLE_STALKER,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_MORMIN_TROLL,	/*  */
		+1, +5, },
	{ MNSTR_KIND_POLTERGEIST,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_ACID_FLY,	/*  */
		+1, +5, },
	{ MNSTR_KIND_FIRE_ELEMENTAL,	/*  */
		+1, +5, },
	{ MNSTR_KIND_HIPPOGRIFF,	/*  */
		+1, +5, },
	{ MNSTR_KIND_WATER_ELEMENTAL,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GIANT_BEETLE,	/*  */
		+1, +5, },
	{ MNSTR_KIND_JACK_O_LANTERN,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GHOST,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_WOOD_GOLEM,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_GRIFFON,	/*  */
		+1, +5, },
	{ MNSTR_KIND_BONE_GOLEM,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_INCUBUS,	/*  */
		+1, +5, },
	{ MNSTR_KIND_SPORE,	/* ʪ */
		+1, +5, },
	{ MNSTR_KIND_ANDRO_SCORPION,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_AIR_ELEMENTAL,	/*  */
		+1, +5, },
	{ MNSTR_KIND_EARTH_ELEMENTAL,	/*  */
		+1, +5, },
	{ MNSTR_KIND_LAMIA,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_CENTAUR,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_WIGHT,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_FLESH_GOLEM,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_BIRD_MAN,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_SUCCUBUS,	/*  */
		+1, +5, },
	{ MNSTR_KIND_MANTICORE,	/*  */
		+1, +5, },
	{ MNSTR_KIND_WEREWOLF,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_WILL_O_WISP,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GAS_CLOUD,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_SHADE,	/*  */
		+1, +5, },
	{ MNSTR_KIND_MINOTAUR,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_CHIMERA,	/*  */
		+1, +5, },
	{ MNSTR_KIND_FIRE_GIANT,	/*  */
		+1, +5, },
	{ MNSTR_KIND_MUMMY,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_FROST_GIANT,	/*  */
		+1, +5, },
	{ MNSTR_KIND_GARGOYLE,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_STONE_GOLEM,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_CLOUD_GIANT,	/*  */
		+1, +5, },
	{ MNSTR_KIND_DURAHAN,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_IRON_GOLEM,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_MOUNTAIN_GIANT,	/*  */
		+1, +5, },
	{ MNSTR_KIND_SALAMANDER,	/*  */
		+1, +5, },
	{ MNSTR_KIND_MIMIC,	/* ˡʪ */
		+1, +5, },
	{ MNSTR_KIND_UNICORN,	/*  */
		+1, +5, },
	{ MNSTR_KIND_CYCLOPS,	/*  */
		+1, +5, },
	{ MNSTR_KIND_UNDINE,	/*  */
		+1, +5, },
	{ MNSTR_KIND_BANSHEE,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_GNOME,	/*  */
		+1, +5, },
	{ MNSTR_KIND_SYLPH,	/*  */
		+1, +5, },
	{ MNSTR_KIND_WYVERN,	/*  */
		+1, +5, },
	{ MNSTR_KIND_MEDUSA,	/* Ⱦ */
		+1, +5, },
	{ MNSTR_KIND_M_RED_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_M_BLUE_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_M_YELLOW_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_M_GREEN_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_WRAITH,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_HYDRA,	/*  */
		+1, +5, },
	{ MNSTR_KIND_LESSER_DEMON,	/*  */
		+1, +5, },
	{ MNSTR_KIND_M_WHITE_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_M_BLACK_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_COCKATRICE,	/*  */
		+1, +5, },
	{ MNSTR_KIND_CERBERUS,	/*  */
		+1, +5, },
	{ MNSTR_KIND_VAMPIRE,	/* ǥå */
		+1, +5, },
	{ MNSTR_KIND_M_COPPER_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_M_SILVER_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_M_GOLD_DRAGON,	/* --ޥʡɥ饴 */
		+1, +5, },
	{ MNSTR_KIND_GORGON,	/*  */
		+1, +5, },
	{ MNSTR_KIND_EFREET,	/*  */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_DJINNI,	/*  */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_BASILISK,	/*  */
		+1, +5, },
	{ MNSTR_KIND_PHOENIX,	/*  */
		+1, +5, },
	{ MNSTR_KIND_HELLHOUND,	/*  */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_SPIRIT,	/* ǥå */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_GREATER_DEMON,	/*  */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_RED_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_BLUE_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_YELLOW_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_GREEN_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_WHITE_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_BLACK_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_COPPER_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_SILVER_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	{ MNSTR_KIND_A_GOLD_DRAGON,	/* --󥷥ȡɥ饴 */
		+1, +DUN_MAX_LEV_BASE, },
	/**/

	{ MNSTR_KIND_NULL,
		+0, +0, },
};

/***************************************************************
* Ǥ NPC νиΨꥹ
***************************************************************/

typedef struct {
	mnstr_kind_t	kind;
	ratio_t	ratio;
} towner_tab_t;

towner_tab_t	towner_tab[] = {
	{
		MNSTR_KIND_FIGHTER,
		1,
	},
	{
		MNSTR_KIND_MONK,
		1,
	},
	{
		MNSTR_KIND_HUNTER,
		1,
	},
	{
		MNSTR_KIND_THIEF,
		1,
	},
	{
		MNSTR_KIND_WIZARD,
		1,
	},
	{
		MNSTR_KIND_SUMMONER,
		1,
	},
	{
		MNSTR_KIND_PRIEST,
		1,
	},
	{
		MNSTR_KIND_SHAMAN,
		1,
	},
	{
		MNSTR_KIND_BARD,
		1,
	},
	{
		MNSTR_KIND_NINJA,
		1,
	},
	{
		MNSTR_KIND_BISHOP,
		1,
	},
	{
		MNSTR_KIND_FARMER,
		5,
	},
	{
		MNSTR_KIND_CRAFTSMAN,
		3,
	},
	{
		MNSTR_KIND_MERCHANT,
		1,
	},
	{
		MNSTR_KIND_NULL,
		0,
	},
};

#endif	/* MNSTR_TAB_H */
